"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
class ImportGenerator {
    srcFolder;
    srcModuleName;
    /**
     * @param srcPath The path (including filename) of the module we're generating imports for.
     */
    constructor(srcPath) {
        this.srcFolder = path_1.default.dirname(srcPath);
        this.srcModuleName = path_1.default.basename(srcPath);
    }
    importMap = {};
    addImport({ name, isDefault, path: absolutePath, isAbsolute, importAsType, }) {
        let importPath = absolutePath;
        if (!isAbsolute) {
            let relativePath = path_1.default.relative(this.srcFolder, absolutePath);
            // We never want Windows-style paths in our source. Fix it if necessary.
            if (path_1.default.sep === '\\') {
                relativePath = relativePath.replaceAll('\\', '/');
            }
            if (relativePath[0] !== '.') {
                relativePath = `./${relativePath}`;
            }
            importPath = relativePath;
        }
        // Ignore imports of "self".
        if (importPath === `./${this.srcModuleName}`) {
            return;
        }
        if (!(importPath in this.importMap)) {
            this.importMap[importPath] = { named: new Set(), namedAsType: new Set() };
        }
        const importSet = this.importMap[importPath];
        if (isDefault) {
            if (importAsType) {
                if (importSet.defaultAsType && importSet.defaultAsType !== name) {
                    throw new Error(`Multiple default imports attempted: ${importSet.defaultAsType} and ${name} from '${importPath}'`);
                }
                importSet.defaultAsType = name;
            }
            else {
                if (importSet.default && importSet.default !== name) {
                    throw new Error(`Multiple default imports attempted: ${importSet.default} and ${name} from '${importPath}'`);
                }
                importSet.default = name;
            }
        }
        else {
            if (importAsType) {
                importSet.namedAsType.add(name);
            }
            else {
                importSet.named.add(name);
            }
        }
    }
    generateLines() {
        return Object.keys(this.importMap).flatMap((relativePath) => {
            const { default: defaultImport, defaultAsType: defaultAsTypeImport, named, namedAsType, } = this.importMap[relativePath];
            const lines = [];
            if (defaultImport || named.size > 0) {
                lines.push(this.generateLine(relativePath, false, defaultImport, [...named]));
            }
            if (defaultAsTypeImport || namedAsType.size > 0) {
                lines.push(this.generateLine(relativePath, true, defaultAsTypeImport, [
                    ...namedAsType,
                ]));
            }
            return lines;
        });
    }
    generateLine(relativePath, importAsType, defaultImport, namedImports) {
        const importDefaultAsNamed = importAsType && defaultImport && namedImports.length > 0;
        const appliedDefaultImport = importDefaultAsNamed
            ? undefined
            : defaultImport;
        const appliedNamedImports = importDefaultAsNamed
            ? [`default as ${defaultImport}`, ...namedImports]
            : namedImports;
        const allImports = [
            ...(appliedDefaultImport ? [appliedDefaultImport] : []),
            ...(appliedNamedImports.length > 0
                ? [`{ ${appliedNamedImports.join(', ')} }`]
                : []),
        ].join(', ');
        return `import ${importAsType ? 'type ' : ''}${allImports} from '${relativePath}';`;
    }
}
exports.default = ImportGenerator;
