"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const generateIndexFile = (outputAcc, instantiatedConfig) => {
    const allEntities = Object.values(instantiatedConfig.schemas).reduce((acc, elem) => {
        const entitiesInSchema = Object.values(elem)
            .filter((e) => Array.isArray(e))
            .flat();
        return [...acc, ...entitiesInSchema];
    }, []);
    const lines = allEntities.map((d) => {
        let result;
        const { path, name: selectorName } = instantiatedConfig.getMetadata(d, 'selector', instantiatedConfig);
        let importPath = (0, path_1.relative)(instantiatedConfig.outputPath, path);
        // We never want Windows-style paths in our source. Fix it if necessary.
        if (path_1.sep === '\\') {
            importPath = importPath.replaceAll('\\', '/');
        }
        if (d.kind === 'table') {
            const additionalImports = [];
            const { name: initializerName } = instantiatedConfig.getMetadata(d, 'initializer', instantiatedConfig);
            additionalImports.push(initializerName);
            const { name: mutatorName } = instantiatedConfig.getMetadata(d, 'mutator', instantiatedConfig);
            additionalImports.push(mutatorName);
            if (instantiatedConfig.generateIdentifierType) {
                const identifierColumns = d.columns.filter((c) => c.isPrimaryKey && !c.reference);
                identifierColumns.forEach((c) => {
                    const { name } = instantiatedConfig.generateIdentifierType(c, d, instantiatedConfig);
                    additionalImports.push(name);
                });
            }
            result = `export type { default as ${selectorName}, ${additionalImports.join(', ')} } from './${importPath}';`;
        }
        else if (d.kind === 'enum') {
            const prefix = instantiatedConfig.enumStyle === 'type' ? 'type ' : '';
            result = `export ${prefix}{ default as ${selectorName} } from './${importPath}';`;
        }
        else {
            result = `export type { default as ${selectorName} } from './${importPath}';`;
        }
        return result;
    });
    const indexFile = {
        declarations: [
            {
                declarationType: 'generic',
                lines,
            },
        ],
    };
    const path = (0, path_1.join)(instantiatedConfig.outputPath, 'index');
    return {
        ...outputAcc,
        [path]: indexFile,
    };
};
exports.default = generateIndexFile;
